@@ -1,5 +1,5 @@
 ## File Name: summary_starts_uni_print_model_fit.R
-## File Version: 0.04
+## File Version: 0.07
 
 summary_starts_uni_print_model_fit <- function(object, digits_fit=3)
 {
@@ -7,8 +7,8 @@ summary_starts_uni_print_model_fit <- function(object, digits_fit=3)
         cat("-----------------------------------------------------------------\n")
         cat("Model Fit \n\n")
         cat( paste0("Chi square test of model fit: \nChi2(df=", object$model_fit$df_sem,
-                    ")=", round( object$model_fit$chisq, digits_fit ), ", p=",
-                    round( object$model_fit$p_chisq, digits_fit ), "\n\n") )
+                    ")", " ", "=", " ", round( object$model_fit$chisq, digits_fit ),
+                    ", p", " ", "=", " ", round( object$model_fit$p_chisq, digits_fit ), "\n\n") )
         cat( "SRMR", "=", round( object$model_fit$SRMR, digits_fit ), "\n" )
         cat( "RMSEA", "=", round( object$model_fit$RMSEA, digits_fit ), "\n" )
     }
